==> haskell-echo-0.1.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-BlErO49OOLiLJPizijFtq4
key: echo-0.1.3-BlErO49OOLiLJPizijFtq4
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
abi: 84c8b228a25ca48df338a9c0286538f1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/echo-0.1.3
hs-libraries: HSecho-0.1.3-BlErO49OOLiLJPizijFtq4
depends:
    base-4.10.1.0 process-1.6.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-echo-0.1.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-G7cuM0pWhoYJlNCMI5dtUe
key: echo-0.1.3-G7cuM0pWhoYJlNCMI5dtUe
license: BSD-3-Clause
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Ryan Scott
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
abi: 4964f47f195bfbb1250f2ddd1b0160d9
exposed: True
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
import-dirs: /usr/lib/ghc-8.4.2/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.4.2/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/echo-0.1.3
hs-libraries: HSecho-0.1.3-G7cuM0pWhoYJlNCMI5dtUe
depends:
    base-4.11.1.0 process-1.6.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
